module txab_spi_if

// Inputs from J1

(
input       txab_sclk,     // Pin 37
input       txab_scsn,     // From 39
input       txab_mosi,     // From 31
input [3:0] txab_addr,     // From 38, 40, 5, 6
input       txab_miso,	   // 21 for USB test purpose only
//output reg  txab_miso,	   // 21 

// Inputs from FTDI 

input		usb_clk,		// FTDI pin 1        D0
input		usb_oe,	              // FTDI pin 2        D4
input		usb_data,	// FTDI pin 5        D1
input		usb_cdc_le,	// FTDI pin 9        D5
input		usb_dac_en,	// FTDI pin 3        D2
input		usb_trf_en,	// FTDI pin 11      D3
input		usb_att_en,	// FTDI pin 10      D6

// Output to FTDI

output reg  usb_dac_sdo_o, 	// FTDI pin 6

// Output to Attenuator 

output      att_le,  // Pin 3


// Input and Outputs to CDC

output      cdce10086_scsn,  // pin 12
output      cdce10086_sclk,  // pin 13
output      cdce10086_mosi,  // pin 15
input       cdce10086_miso,  // pin 14

// Input and Outputs from TRF3720

input       trf_rdbk, // pin 27 
output      trf_le,   // pin 28

// Input and Outputs to DAC

input       dac_alarm_sdo,   // pin 10 
output      dac3484_scsn,    // pin 25   
output      txab_spi_sclk,   // pin 33, SPI clk to DAC, CDC, LE
inout       txab_spi_data    // pin 31, SPI data to DAC, CDC, LE
);



assign txab_spi_sclk = usb_clk;        // Output clock to DAC, TRF, LE,  
assign txab_spi_data = (usb_oe & ~usb_dac_en) ? 1'bz : usb_data; // Read SPI data from DAC


assign cdce10086_sclk = usb_clk;       // Output to CDC clock 
assign cdce10086_mosi = usb_data;      // Output to data to CDC
assign cdce10086_scsn = usb_cdc_le;    // Output to CDC enable


assign dac3484_scsn = usb_dac_en;     // Output to DAC enable
assign att_le = usb_att_en;           // Output to ATT enable
assign trf_le = usb_trf_en;           // Output to ATT enable



// Readback Mux

always @ (*)
begin
	if (~usb_dac_en & usb_oe)
         usb_dac_sdo_o <= txab_spi_data;
   //if (~usb_cdc_le & usb_oe)
      //usb_dac_sdo_o <= cdce10086_miso; // Read CDC
   else
   begin
	if (~usb_cdc_le & usb_oe)
      usb_dac_sdo_o <= cdce10086_miso;
     //if (~usb_dac_en & usb_oe)
         //usb_dac_sdo_o <= txab_spi_data; // DAC three wire mode
       //usb_dac_sdo_o <= dac_alarm_sdo; // DAC four wire mode
     else	
	   begin
		   if (~usb_trf_en & usb_oe)
			   usb_dac_sdo_o <= trf_rdbk; // Read TRF
           else
               usb_dac_sdo_o <= 1'bz;
       end         
   end 
 end
 
    
endmodule 